# ExternalAPIOrderOriginsAssortmentsRequest


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**origin_assortment_raw_id** | **str** | Origin assortment raw id. | [optional] 

## Example

```python
from openapi_client.models.external_api_order_origins_assortments_request import ExternalAPIOrderOriginsAssortmentsRequest

# TODO update the JSON string below
json = "{}"
# create an instance of ExternalAPIOrderOriginsAssortmentsRequest from a JSON string
external_api_order_origins_assortments_request_instance = ExternalAPIOrderOriginsAssortmentsRequest.from_json(json)
# print the JSON string representation of the object
print(ExternalAPIOrderOriginsAssortmentsRequest.to_json())

# convert the object into a dict
external_api_order_origins_assortments_request_dict = external_api_order_origins_assortments_request_instance.to_dict()
# create an instance of ExternalAPIOrderOriginsAssortmentsRequest from a dict
external_api_order_origins_assortments_request_from_dict = ExternalAPIOrderOriginsAssortmentsRequest.from_dict(external_api_order_origins_assortments_request_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


